
// VcDemoDlg.h : header file
//

#pragma once

#include "VideoWin.h"
#include "atltypes.h"

typedef struct {
	unsigned devIndex;
	unsigned audioDev;
	unsigned videoSource;
	BOOL bSoundOut;
	BOOL bSignal;
	BOOL bMute;
	BOOL bFlip;
	BOOL bMirror;
	BOOL bTimeOSD;
	BOOL bTextOSD_1;
	BOOL bTextOSD_2;
	BOOL bPictureOSD;
	BOOL bEncode;
	BOOL bRecord;
	BOOL bRecAudio;
	BOOL bNetTrans;
	BOOL bNetAudio;
	int nNetProtcol;
	float fFrameRate;
	unsigned nWidth;
	unsigned nHeight;
	unsigned nStandard;
	device_handle devHandle;
	CVideoWin *pVideoWin;
} DXDEVINFO, *PDXDEVINFO;

typedef struct {
	unsigned streamType;
	unsigned streamControl;
	unsigned encoderType;
	unsigned frameRatio;
	unsigned bitrate;
} ENCODEINFO, *PENCODEINFO;

typedef struct {
	unsigned rtspEnable;
	unsigned rtspPort;
	unsigned rtmpEnable;
	unsigned audioEnable;
	CString strUri;
} NETSTREAMINFO, *PNETSTREAMINFO;

typedef struct {
	unsigned videoRender;
	unsigned videoWidth;
	unsigned videoHeight;
	unsigned videoFramerate;
	unsigned videoStandard;
	unsigned videoDeinterlace;
} VIDEOINFO, *PVIDEOINFO;

typedef struct {
	unsigned osdEnable[4];
} OSDENABLE, *POSDENABLE;

typedef enum {
	win_mode_1,
	win_mode_4, // 2x2
	win_mode_9, // 3x3
	win_mode_16 // 4x4
} win_mode_e;

// CVcDemoDlg dialog
class CVcDemoDlg : public CDialogEx
{
// Construction
public:
	CVcDemoDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	enum { IDD = IDD_VCDEMO_DIALOG };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support


// Implementation
protected:
	HICON m_hIcon;

	// Generated message map functions
	virtual BOOL OnInitDialog();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	DECLARE_MESSAGE_MAP()
	afx_msg LRESULT OnVideowinMsg(WPARAM wParam, LPARAM lParam);

	unsigned int m_uDevCount;
	DXDEVINFO m_DxDev[MAX_DXDEV_NUM];
	CRect m_WinRect;
	CFont m_Font;
	CBrush m_Brush;
	unsigned int m_uDevSelect;
	void SetVideoWinMode(int nStart, win_mode_e mode);
	win_mode_e m_WinMode;
	win_mode_e m_WinOldMode;
public:
	afx_msg void OnDestroy();
	void FullScreenVideoFlip();
	void FullScreenVideoMirror();
	void ExitFullScreen();
	unsigned GetCurrentDev(void) { return m_uDevSelect; }
	PDXDEVINFO GetDevInfo(int nIndex) { if (nIndex >= 0 && nIndex < MAX_DXDEV_NUM) { return &m_DxDev[nIndex]; } return NULL; }
protected:
	void SelectVideoWin(void);
	void SetVideoStatus(unsigned int nIndex);
	void SetAudioDevice(unsigned int nIndex);
	void SetVideoParam(unsigned int nIndex);
	void SetVideoSource(unsigned int nIndex);
	void SetVideoDeinterlace(unsigned int nIndex);
	void SetTimeOSD(unsigned int nIndex);
	void SetTextOSD_1(unsigned int nIndex);
	void SetTextOSD_2(unsigned int nIndex);
	void SetPictureOSD(unsigned int nIndex);
	void VideoPreviewStart(unsigned int nIndex);
	void VideoPreviewStop(unsigned int nIndex);
	void DeviceStart(unsigned int nIndex);
	void DeviceRestart(unsigned int nIndex);
	BOOL RecordStart(unsigned int nIndex);
	void RecordStop(unsigned int nIndex);
	void RecordControl(unsigned int nIndex);
	void NetStreamStart(unsigned int nIndex);
	void NetStreamStop(unsigned int nIndex);
	BOOL EncodeCallbackControl(unsigned int nIndex, BOOL bStart);
	BOOL GetFilename(CString &strFile, LPCSTR strExtend);
	void GetEncodeSetting(unsigned nIndex, ENCODEINFO &info);
	void GetNetSetting(unsigned nIndex, NETSTREAMINFO &info);
	void GetVideoSetting(unsigned nIndex, VIDEOINFO &info, BOOL bHD);
	void GetOSDEnable(unsigned nIndex, OSDENABLE &en);
public:
	afx_msg void OnSelchangeVideosource();
	afx_msg void OnSelchangeAudiodev();
	afx_msg void OnBnClickedMute();
	afx_msg void OnBnClickedSavesetting();
	afx_msg void OnBnClickedReccontrol();
	afx_msg void OnTimer(UINT_PTR nIDEvent);
	afx_msg void OnBnClickedEncsetting();
	afx_msg void OnBnClickedVideosnapshot();
	afx_msg void OnBnClickedNetsetting();
	afx_msg void OnBnClickedVideosetting();
	afx_msg void OnBnClickedOsdsetting();
	afx_msg void OnBnClickedVideoFlip();
	afx_msg void OnBnClickedVideoMirror();
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	afx_msg void OnBnClickedFullscreen();
	afx_msg void OnBnClickedRepairmp4file();
	afx_msg void OnBnClickedMp4filecut();
};
